
#define __GNU_PROLOG__        	1
#define __GPROLOG__           	1
#define __GPROLOG_MINOR__     	4
#define __GPROLOG_PATCHLEVEL__	2
#define __GPROLOG_VERSION__   	10402

#define PROLOG_DIALECT  	"gprolog"
#define PROLOG_NAME     	"GNU Prolog"
#define PROLOG_VERSION  	"1.4.2"
#define PROLOG_DATE     	"Dec  3 2012"
#define PROLOG_COPYRIGHT	"Copyright (C) 1999-2012 Daniel Diaz"

#define PL_MIN_INTEGER		-268435456
#define PL_MAX_INTEGER		268435455

#define PL_REF        		0 
#define PL_LST        		1 
#define PL_STC        		2 
#define PL_ATM        		3 
#define PL_FLT        		4 
#define PL_FDV        		5 
#define PL_INT        		7 
